pub trait MigrationSource<DB: Backend> {
// Required method
fn migrations(&self) -> Result<Vec<Box<dyn Migration<DB>>>>;
}Expand description
A migration source is an entity that can be used to receive a number of migrations from.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".